AsyncHandler mixin

Superclass constraints

Properties

context BuildContext
The BuildContext of the nearest ControllerProvider ancestor.
getter/setter pairinherited
error Object?
getter/setter pairinherited
hasError bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isDisposed bool
no setterinherited
isInitialized bool
no setterinherited
isReady bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeContext BuildContext?
no setterinherited
type Type
Returns the runtime type of this controller.
no setterinherited
value ↔ dynamic
The current value stored in this notifier.
getter/setter pairinherited

Methods

addDisposable(Disposable disposable) → void
inherited
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearError() → void
inherited
dependOn<T extends ReignController>() → T
Retrieves another controller of type T from the store.
inherited
dispose() → void
Disposes the controller, cleaning up resources and unregistering from the store.
inherited
handleAsync<T>(Future<T> fn()) Future<T>
override
init() → void
inherited
initialize() → void
inherited
markReady() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onDispose() → void
inherited
onInit() → void
inherited
onReady() → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
update() → void
Notifies all listeners that the controller's state has changed.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited