ReignController<T> constructor

ReignController<T>(
  1. T initialValue, {
  2. bool register = true,
})

Creates a controller and optionally registers it with the ControllerStore.

If register is true (default), the controller will be registered with the store and can be accessed via ControllerProvider.of or dependOn.

Implementation

ReignController(T initialValue, {bool register = true})
    : super(initialValue) {
  if (register) {
    _store.save(this);
  }
}