Disposable mixin

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setterinherited
isInitialized bool
no setterinherited
isReady bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDisposable(Disposable disposable) → void
dispose() → void
override
init() → void
inherited
initialize() → void
inherited
markReady() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → void
inherited
onInit() → void
inherited
onReady() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited