ReignBuilder<T extends ReignController> class
Widget that builds itself whenever the provided controller changes.
Two main usage patterns:
- Create new controller:
ReignBuilder<CounterController>(
create: () => CounterController(),
builder: (context, controller) => Text('${controller.value}'),
)
- Use existing controller:
ReignBuilder<CounterController>.use(
builder: (context, controller) => Text('${controller.value}'),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ReignBuilder
Constructors
- ReignBuilder({Key? key, T? controller, T create()?, required Widget builder(BuildContext context, T controller), ThemeData? theme, Widget? loading, Widget error(Object error)?})
-
const
- ReignBuilder.use({Key? key, required Widget builder(BuildContext context, T controller), ThemeData? theme, Widget? loading, Widget error(Object error)?})
-
const
Properties
- builder → Widget Function(BuildContext context, T controller)
-
final
- controller → T?
-
final
- create → T Function()?
-
final
- error → Widget Function(Object error)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loading → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeData?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ReignBuilder< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited