ControllerNotFoundError class
Error thrown when a requested controller isn't found in the store.
Typically occurs when:
- Controller wasn't registered
- Wrong type parameter used
- Accessed before initialization
Constructors
- ControllerNotFoundError(Type controllerType)
Properties
- controllerType → Type
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited