ControllerStore class
Central registry for managing controller instances.
Use this singleton to:
Example:
final store = ControllerStore.instance;
store.save(MyController());
final controller = store.use<MyController>();
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
ReignController controller, VoidCallback listener) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
ReignController controller) → void -
remove(
Type type) → void -
removeListener(
ReignController controller, VoidCallback listener) → void -
reset(
) → void -
save(
ReignController controller) → void -
toString(
) → String -
A string representation of this object.
inherited
-
use<
T extends ReignController> () → T
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- debugMode ↔ bool
-
getter/setter pair
- instance → ControllerStore
-
final